Changelog
=========

1.0.2 (2022-11-23)
------------------

- supports polygon format now (index + pairs of normalized x/y coordinates)
- `YOLOODReader` now skips annotations if it fails to locate associated image


1.0.1 (2022-09-05)
------------------

- the `read_labels_file` method of `FromYOLOOD` now strips leading/trailing whitespaces
  from the labels.


1.0.0 (2022-03-01)
------------------

- Initial release.
